==> gtkatlantic-0.4.0.tar.bz2: gtkatlantic-0.4.0/src/trade.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright (C) 2002-2004 Rochet Sylvain
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <gtk/gtk.h>


void trade_initnew(guint32 tradeid);
void trade_destroy(guint32 tradeid);
void trade_destroy_slot(guint32 tradeslot);
void trade_create_panel(guint32 tradeslot);
void trade_rebuild_playerlist(guint32 tradeslot);
void trade_rebuild_component(guint32 tradeslot);
void trade_rebuild_subcomponent(guint32 tradeslot);
void trade_update_player(gint32 tradeid, gint32 playerid, gboolean accept);
void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer);
void trade_update_estate(gint32 tradeid, gint32 estateid, gint32 targetplayer);
void trade_update_money(gint32 tradeid, gint32 playerfrom, gint32 playerto, gint32 money);

==> gtkatlantic-0.4.3.tar.bz2: gtkatlantic-0.4.3/src/trade.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright (C) 2002-2010 Rochet Sylvain
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <gtk/gtk.h>


void trade_initnew(gint32 tradeid);
void trade_destroy(gint32 tradeid);
void trade_destroy_slot(gint32 tradeslot);
void trade_create_panel(gint32 tradeslot);
void trade_rebuild_playerlist(gint32 tradeslot);
void trade_rebuild_component(gint32 tradeslot);
void trade_rebuild_subcomponent(gint32 tradeslot);
void trade_update_player(gint32 tradeid, gint32 playerid, gboolean accept);
void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer);
void trade_update_estate(gint32 tradeid, gint32 estateid, gint32 targetplayer);
void trade_update_money(gint32 tradeid, gint32 playerfrom, gint32 playerto, gint32 money);
